decode_invocation_params

Function decode_invocation_params 

pub fn decode_invocation_params<I>(
    payload: impl AsRef<[u8]>,
) -> Result<I::Params>
where I: InvocationIo, I::Params: Decode,
Decode the SCALE-encoded Params of an invocation, validating that the Sails message header’s interface id and entry id match the target I.