value

Function value 

pub fn value() -> u128
Get the value associated with the message that is being processed.

This function returns the value that has been sent along with a current message that is being processed.

Examples

use gcore::msg;

#[unsafe(no_mangle)]
extern "C" fn handle() {
    let amount_sent_with_message = msg::value();
}