InvocationIo

Trait InvocationIo 

pub trait InvocationIo: MethodMeta {
    type Params;
}
Invocation parameter metadata for a generated service method.

This trait intentionally does not require Params: Decode. SCALE dispatch adds that bound at the call site through decode_invocation_params, while ABI-only methods can still use the same metadata type without requiring SCALE codec support for their parameters.

Required Associated Types

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors