gr_create_program

Function gr_create_program 

pub unsafe extern "C" fn gr_create_program(
    cid_value: *const HashWithValue,
    salt: *const u8,
    salt_len: u32,
    payload: *const u8,
    payload_len: u32,
    delay: u32,
    err_mid_pid: *mut ErrorWithTwoHashes,
)
Fallible gr_create_program send syscall.

Arguments type:

  • cid_value: const ptr for concatenated code id and value.
  • salt: const ptr for the begging of the salt buffer.
  • salt_len: u32 length of the salt buffer.
  • payload: const ptr for the begging of the payload buffer.
  • payload_len: u32 length of the payload buffer.
  • delay: u32 amount of blocks to delay.
  • err_mid_pid: mut ptr for concatenated error code, message id and program id.